@@ -137,38 +137,6 @@ class DirectChannel(RequestWrapper):
         url = "{0}/{1}".format(self.url, 'wsc_get_regulars.ashx')
         return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
 
-    def wsc_save_donation(self, idregolare=None, codicedonatore=None, codicecampagna=None, codicecentro=None,
-                          codicebambino=None, codiceprogetto=None, codicecanale=None, importo=None, metodo=None,
-                          dataoperazione=None,
-                          datavaluta=None, codicetransizione=None, idweb=None, note=None):
-        payload = {
-            "env": self.env,
-            "application": self.application,
-            "operation": "save",
-            "token": self.token,
-            "user": self.user,
-            "param": "",
-            "data": {
-                "idRegolare": idregolare,
-                "codiceDonatore": codicedonatore,
-                "codiceCampagna": codicecampagna,
-                "codiceCentro": codicecentro,
-                "codiceBambino": codicebambino,
-                "codiceProgetto": codiceprogetto,
-                "codiceCanale": codicecanale,
-                "importo": importo,
-                "metodo": metodo,
-                "dataOperazione": dataoperazione,
-                "dataValuta": datavaluta,
-                "codiceTransazione": codicetransizione,
-                "idWeb": idweb,
-                "note": note
-            }
-        }
-        headers = {'content-type': 'application/json'}
-        url = "{0}/{1}".format(self.url, 'wsc_save_donation.ashx')
-        return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
-
     def wsc_save_profile(self, codicedonatore=None, codiceprofilazione=None, descrizioneranking=None, 
                          codicecampagna=None, dataentrata=None, datauscita=None):
         payload = {
@@ -296,6 +264,41 @@ class DirectChannel(RequestWrapper):
                 "data": "",
             }
 
+    def wsc_save_donation(self, codicedonatore=None, codicecampagna=None, codicecentro=None, codicecanale=None, codicebambino=None,
+                          codiceprogetto=None, codiceconto=None, importo=None, metodo=None, note=None, dataoperazione=None, datavaluta=None,
+                          idregolare=None, idweb=None, codicetransazione=None, tipo=None, evento=None):
+        payload = {
+            "env": self.env,
+            "application": self.application,
+            "operation": "save",
+            "token": self.token,
+            "user": self.user,
+            "param": "",
+            "data": {
+                "codiceDonatore": codicedonatore,
+                "codiceDonatore": codicedonatore,
+                "codiceCampagna": codicecampagna,
+                "codiceCentro": codicecentro,
+                "codiceCanale": codicecanale,
+                "codiceBambino": codicebambino,
+                "codiceProgetto": codiceprogetto,
+                "codiceConto": codiceconto,
+                "importo": importo,
+                "metodo": metodo,
+                "note": note,
+                "dataOperazione": dataoperazione,
+                "dataValuta": datavaluta,
+                "idRegolare": idregolare,
+                "idWeb": idweb,
+                "codiceTransazione": codicetransazione,
+                "tipo": tipo,
+                "evento": evento,
+            }
+        }
+        
+        headers = {'content-type': 'application/json'}
+        url = "{0}/{1}".format(self.url, 'wsc_save_activity.ashx')
+        return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
 
     def wsc_save_activity(self, codicedonatore=None, codicecampagna=None, codicebambino=None, codiceprogetto=None,
                           codicecanale=None, idregolare=None, tipo=None, sottotipo=None,
@@ -350,6 +353,24 @@ class DirectChannel(RequestWrapper):
         headers = {'content-type': 'application/json'}
         url = "{0}/{1}".format(self.url, 'wsc_save_privacy.ashx')
         return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
+    
+    def wsc_set_spec(self, codicedonatore, codicecampo, valore):
+        payload = {
+            "env": self.env,
+            "application": self.application,
+            "operation": "save",
+            "token": self.token,
+            "user": self.user,
+            "param": "",
+            "data": {
+                "codiceAnagrafica": codicedonatore,
+                "codiceCampo": codicecampo,
+                "valore": valore
+            }
+        }
+        headers = {'content-type': 'application/json'}
+        url = "{0}/{1}".format(self.url, 'wsc_save_privacy.ashx')
+        return self._handle_data(self._send_request(url=url, payload=payload, headers=headers, debug=self.debug))
 
 
     def wsc_call_regular(self, idRegolare, codiceEsito):
